AutoArchive._infrastructure.utils.constants — AutoArchive Developer Manual (ver. 2.1.0.dev20260309)

# Source code for AutoArchive._infrastructure.utils.constants

    # constants.py
    #
    # Project: AutoArchive
    # License: GNU GPLv3
    #
    # Copyright (C) 2003 - 2026 Róbert Čerňanský

    __all__ = ["Constants"]

    import os
    from abc import ABCMeta, abstractmethod

    class Constants(metaclass = ABCMeta):
        "Defines various “global” constants."

        #: Debugging support.
        DEBUG = os.environ.get("AADEBUG")

        #: Prefix for names of temporary files
        TEMP_FILE_PREFIX = "autoarchive"

        @abstractmethod
        def __init__(self):
            pass